@@ -82,6 +82,8 @@ desks_schema = {
     },
     # if the preserve_published_content is set to true then the content on this won't be expired
     "preserve_published_content": {"type": "boolean", "required": False, "default": False},
+    # Store SAMS's Desk settings on the Desk items
+    "sams_settings": {"type": "dict", "allow_unknown": True, "schema": {"allowed_sets": {"type": "list"}}},
 }
 
 
@@ -295,22 +297,6 @@ class DesksService(BaseService):
         else:
             push_notification(self.notification_key, updated=1, desk_id=str(desk.get(config.ID_FIELD)))
 
-    def apply_desk_metadata(self, updates, original):
-        """Apply desk metadata in case it was set in updates and metadata is not set yet on item.
-
-        :param updates: updates to item that should be saved
-        :param original: original item version before update
-        """
-        desk_id = updates.get("task", {}).get("desk", {})
-        if not desk_id:
-            return
-        desk = self.find_one(req=None, _id=desk_id)
-        if not desk:
-            return
-        for key, val in desk.get("desk_metadata", {}).items():
-            if key not in updates and key not in original:
-                updates[key] = val
-
     def get_desk_name(self, desk_id):
         """Return the item desk.
 
@@ -324,17 +310,17 @@ class DesksService(BaseService):
 
         return desk_name
 
-    def get(self, req, lookup):
-        desks = tuple(super().get(req, lookup))
-
+    def on_fetched(self, res):
         members_set = set()
         db_users = app.data.mongo.pymongo("users").db["users"]
 
         # find display_name from the users document for each member in desks document
-        for desk in desks:
+        for desk in res["_items"]:
             if "members" in desk:
                 users = tuple(
-                    db_users.find({"_id": {"$in": [member["user"] for member in desk["members"]]}}, {"display_name": 1})
+                    db_users.find(
+                        {"_id": {"$in": [member["user"] for member in desk.get("members", [])]}}, {"display_name": 1}
+                    )
                 )
                 members_set |= {(m["_id"], m["display_name"]) for m in users}
 
@@ -344,14 +330,14 @@ class DesksService(BaseService):
             sorted_members_ids = tuple(m[0] for m in members_list)
 
             # sort the members of each desk according to ordered_dict
-            for desk in desks:
+            for desk in res["_items"]:
                 if "members" in desk:
                     # remove members which don't exist in db
                     desk["members"] = [member for member in desk["members"] if member["user"] in sorted_members_ids]
                     # sort member in desk
                     desk["members"].sort(key=lambda x: sorted_members_ids.index(x["user"]))
 
-        return ListCursor(desks)
+        return res
 
 
 class UserDesksResource(Resource):
@@ -598,9 +584,12 @@ class OverviewService(BaseService):
                                     CONTENT_STATE.SPIKED,
                                     CONTENT_STATE.KILLED,
                                     CONTENT_STATE.CORRECTED,
+                                    CONTENT_STATE.SCHEDULED,
+                                    CONTENT_STATE.RECALLED,
                                 ]
                             }
-                        }
+                        },
+                        {"term": {"version": 0}},
                     ]
                 }
             }
@@ -665,7 +654,7 @@ class OverviewService(BaseService):
         found = desks_service.get(req, desk_filter)
         members = set()
         for d in found:
-            members.update({m["user"] for m in d["members"]})
+            members.update({m["user"] for m in d.get("members", [])})
 
         users_aggregation = app.data.pymongo().db.users.aggregate(
             [
