@@ -10,7 +10,7 @@
 
 
 import superdesk
-from apps.archive.archive import SOURCE as ARCHIVE
+from apps.archive.archive import SOURCE as ARCHIVE, remove_is_queued
 from apps.content import push_content_notification
 from apps.auth import get_user_id
 from superdesk import get_resource_service
@@ -55,9 +55,9 @@ class TranslateService(BaseService):
         macros_service = get_resource_service("macros")
         published_service = get_resource_service("published")
 
-        item = archive_service.find_one(req=None, guid=guid)
+        item = archive_service.find_one(req=None, _id=guid)
         if not item:
-            raise SuperdeskApiError.notFoundError(_("Fail to found item with guid: {guid}").format(guid=guid))
+            raise SuperdeskApiError.notFoundError(_("Failed to find item with guid: {guid}").format(guid=guid))
 
         if not is_workflow_state_transition_valid("translate", item[ITEM_STATE]):
             raise InvalidStateTransitionError()
@@ -82,6 +82,8 @@ class TranslateService(BaseService):
         if task:
             item["task"] = task
 
+        remove_is_queued(item)
+
         extra_fields = ["translation_id", "translated_from"]
 
         UPDATE_TRANSLATION_METADATA_MACRO = app.config.get("UPDATE_TRANSLATION_METADATA_MACRO")
