@@ -14,7 +14,7 @@ from apps.keywords.service import KeywordsService
 from apps.keywords.alchemy import AlchemyKeywordsProvider
 
 
-def init_app(app):
+def init_app(app) -> None:
     endpoint_name = "keywords"
     service = KeywordsService(endpoint_name, backend=superdesk.get_backend())
     if app.config.get("KEYWORDS_PROVIDER") == "Alchemy":
