@@ -23,7 +23,7 @@ from superdesk.utc import utcnow
 
 from bson.objectid import ObjectId
 from eve.utils import ParsedRequest, config
-from flask import current_app as app
+from flask import current_app as app, request
 
 from apps.archive.archive import SOURCE as ARCHIVE
 from apps.archive.common import handle_existing_data, item_schema
@@ -112,6 +112,12 @@ class PublishedItemResource(Resource):
     item_methods = ["GET", "PATCH"]
     additional_lookup = {"url": 'regex("[\w,.:-]+")', "field": "item_id"}
 
+    mongo_indexes = {
+        "guid_1": ([("guid", 1)], {"background": True}),
+        "item_id_1": ([("item_id", 1)], {"background": True}),
+        "translation_id_1": ([("translation_id", 1)], {"background": True}),
+    }
+
 
 class PublishedItemService(BaseService):
     """
@@ -208,6 +214,10 @@ class PublishedItemService(BaseService):
                     "archive_item": archive_item if archive_item else None,
                 }
 
+                if request and request.args.get("published_id") == "1":
+                    updates.pop(config.ID_FIELD)
+                    updates.pop("item_id")
+
                 item.update(updates)
                 handle_existing_data(item)
 
