@@ -15,7 +15,7 @@ from superdesk import get_backend
 from superdesk.metadata.item import metadata_schema
 
 
-def init_app(app):
+def init_app(app) -> None:
     endpoint_name = "spikes"
     service = BaseService(endpoint_name, backend=get_backend())
     SpikesResource(endpoint_name, app=app, service=service)
