@@ -16,7 +16,7 @@ from .content_templates import ContentTemplatesResource, ContentTemplatesService
 from .content_templates import ContentTemplatesApplyResource, ContentTemplatesApplyService
 from .content_templates import create_scheduled_content  # noqa
 from .content_templates import create_template_for_profile
-from .filters import format_datetime_filter, first_paragraph_filter
+from .filters import format_datetime_filter, first_paragraph_filter, iso_datetime, add_timedelta
 from flask_babel import lazy_gettext
 
 
@@ -41,5 +41,7 @@ def init_app(app) -> None:
     register_jinja_filter("format_datetime", format_datetime_filter)
     register_jinja_filter("first_paragraph", first_paragraph_filter)
     register_jinja_filter("get_text", get_text)
+    register_jinja_filter("iso_datetime", iso_datetime)
+    register_jinja_filter("add_timedelta", add_timedelta)
 
     app.on_inserted_content_types += create_template_for_profile
