@@ -17,5 +17,5 @@ from .vidible import bp
 logger = logging.getLogger(__name__)
 
 
-def init_app(app):
+def init_app(app) -> None:
     superdesk.blueprint(bp, app)
