@@ -13,7 +13,7 @@ from .service import PackagesVersionsService
 from .resource import PackagesVersionsResource
 
 
-def init_app(app):
+def init_app(app) -> None:
     endpoint_name = "packages_versions"
     service = PackagesVersionsService(endpoint_name, backend=superdesk.get_backend())
     PackagesVersionsResource(endpoint_name, app=app, service=service)
