@@ -15,6 +15,7 @@ import superdesk
 from flask import current_app as app
 from superdesk.errors import BulkIndexError
 from superdesk import config
+from bson.objectid import ObjectId
 
 
 class IndexFromMongo(superdesk.Command):
@@ -36,10 +37,11 @@ class IndexFromMongo(superdesk.Command):
         superdesk.Option("--from", "-f", dest="collection_name"),
         superdesk.Option("--all", action="store_true", dest="all_collections"),
         superdesk.Option("--page-size", "-p"),
+        superdesk.Option("--last-id"),
     ]
     default_page_size = 500
 
-    def run(self, collection_name, all_collections, page_size):
+    def run(self, collection_name, all_collections, page_size, last_id):
         if not collection_name and not all_collections:
             raise SystemExit("Specify --all to index from all collections")
         elif all_collections:
@@ -48,11 +50,11 @@ class IndexFromMongo(superdesk.Command):
             for resource in resources:
                 self.copy_resource(resource, page_size)
         else:
-            self.copy_resource(collection_name, page_size)
+            self.copy_resource(collection_name, page_size, last_id)
 
     @classmethod
-    def copy_resource(cls, resource, page_size):
-        for items in cls.get_mongo_items(resource, page_size):
+    def copy_resource(cls, resource, page_size, last_id=None):
+        for items in cls.get_mongo_items(resource, page_size, last_id):
             print("{} Inserting {} items".format(time.strftime("%X %x %Z"), len(items)))
             s = time.time()
             success, failed = 0, 0
@@ -68,6 +70,7 @@ class IndexFromMongo(superdesk.Command):
                     break
 
             print("{} Inserted {} items in {:.3f} seconds".format(time.strftime("%X %x %Z"), success, time.time() - s))
+
             if failed:
                 print("Failed to do bulk insert of items {}. Errors: {}".format(len(failed), failed))
                 raise BulkIndexError(resource=resource, errors=failed)
@@ -75,7 +78,7 @@ class IndexFromMongo(superdesk.Command):
         return "Finished indexing collection {}".format(resource)
 
     @classmethod
-    def get_mongo_items(cls, mongo_collection_name, page_size):
+    def get_mongo_items(cls, mongo_collection_name, page_size, last_id):
         """Generate list of items from given mongo collection per page size.
 
         :param mongo_collection_name: Name of the collection to get the items
@@ -87,12 +90,18 @@ class IndexFromMongo(superdesk.Command):
 
         db = app.data.get_mongo_collection(mongo_collection_name)
         args = {"limit": bucket_size, "sort": [(config.ID_FIELD, pymongo.ASCENDING)]}
-        last_id = None
+
         while True:
             if last_id:
+                try:
+                    last_id = ObjectId(last_id)
+                except Exception:
+                    pass
                 args.update({"filter": {config.ID_FIELD: {"$gt": last_id}}})
+
             cursor = db.find(**args)
             if not cursor.count():
+                print("Last id", mongo_collection_name, last_id)
                 break
             items = list(cursor)
             last_id = items[-1][config.ID_FIELD]
