@@ -160,7 +160,7 @@ ARCHIVED_DBNAME = env("ARCHIVED_DBNAME", "archived")
 #: archived mongodb uri
 ARCHIVED_URI = env("ARCHIVED_URI", "mongodb://localhost/%s" % ARCHIVED_DBNAME)
 
-CONTENTAPI_MONGO_DBNAME = "contentapi"
+CONTENTAPI_MONGO_DBNAME = env("CONTENTAPI_MONGO_DBNAME", "contentapi")
 CONTENTAPI_MONGO_URI = env("CONTENTAPI_MONGO_URI", "mongodb://localhost/%s" % CONTENTAPI_MONGO_DBNAME)
 
 #: elastic url
@@ -358,6 +358,7 @@ CORE_APPS = [
     "superdesk.auth_server",
     "apps.links",
     "superdesk.locales",
+    "apps.usage_metrics",
 ]
 
 #: Specify what modules should be enabled
@@ -559,6 +560,9 @@ PASSWORD_EXPIRY_DAYS = int(env("PASSWORD_EXPIRY_DAYS", 0))
 #: The number of minutes since the last update of the Mongo auth object after which it will be deleted
 SESSION_EXPIRY_MINUTES = int(env("SESSION_EXPIRY_MINUTES", 240))
 
+#: How often update user session/activity timestamp
+SESSION_UPDATE_SECONDS = 30
+
 #: The number of minutes before content items are purged
 CONTENT_EXPIRY_MINUTES = int(env("CONTENT_EXPIRY_MINUTES", 0))
 
@@ -575,11 +579,17 @@ INGEST_EXPIRY_MINUTES = int(env("INGEST_EXPIRY_MINUTES", 2 * 24 * 60))
 PUBLISHED_CONTENT_EXPIRY_MINUTES = int(env("PUBLISHED_CONTENT_EXPIRY_MINUTES", 0))
 
 #: The number of minutes before audit content is purged
-AUDIT_EXPIRY_MINUTES = int(env("AUDIT_EXPIRY_MINUTES", 0))
+#:
+#: .. versionchanged:: 2.4.0
+#     Changed default to 14 days (was previously disabled)
+AUDIT_EXPIRY_MINUTES = int(env("AUDIT_EXPIRY_MINUTES", 60 * 24 * 14))
 
 #: The number records to be fetched for expiry.
 MAX_EXPIRY_QUERY_LIMIT = int(env("MAX_EXPIRY_QUERY_LIMIT", 100))
 
+#: Number of loops to do on each run
+MAX_EXPIRY_LOOPS = 50
+
 #: The number of minutes before Publish Queue is purged
 PUBLISH_QUEUE_EXPIRY_MINUTES = int(env("PUBLISH_QUEUE_EXPIRY_MINUTES", 0))
 
@@ -894,6 +904,10 @@ ARCHIVE_AUTOCOMPLETE_DAYS = 0
 #:
 ARCHIVE_AUTOCOMPLETE_HOURS = 0
 
+#:
+#: .. versionadded:: 2.3.6
+#:
+ARCHIVE_AUTOCOMPLETE_LIMIT = 500
 
 #: Tansa client config
 #:
@@ -964,3 +978,4 @@ OIDC_BROWSER_REDIRECT_URL = env("OIDC_BROWSER_REDIRECT_URL", CLIENT_URL)
 #: .. versionadded:: 2.1
 #:
 APPS_DATA_UPDATES_PATHS = []
+PUBLISH_ASSOCIATIONS_RESEND = "new"
