@@ -9,9 +9,11 @@
 # at https://www.sourcefabric.org/superdesk/license
 
 
+from typing import Dict, Any
 import eve.io.base
-
 import json as std_json
+
+from typing_extensions import Literal
 from pymongo.cursor import Cursor as MongoCursor
 from pymongo.collation import Collation
 from flask import current_app as app, json
@@ -22,7 +24,7 @@ from superdesk.logging import logger, item_msg
 from eve.methods.common import resolve_document_etag
 from elasticsearch.exceptions import RequestError, NotFoundError
 from superdesk.errors import SuperdeskApiError
-from superdesk.notification import push_notification
+from superdesk.notification import push_notification as _push_notification
 
 
 SYSTEM_KEYS = set(
@@ -178,8 +180,10 @@ class EveBackend:
             doc.pop("_type", None)
         ids = self.create_in_mongo(endpoint_name, docs, **kwargs)
         self.create_in_search(endpoint_name, docs, **kwargs)
+
         for doc in docs:
-            push_notification("resource:created", _id=str(doc["_id"]), resource=endpoint_name)
+            self._push_resource_notification("created", endpoint_name, _id=str(doc["_id"]))
+
         return ids
 
     def create_in_mongo(self, endpoint_name, docs, **kwargs):
@@ -225,7 +229,7 @@ class EveBackend:
                 updates[config.ETAG] = updated[config.ETAG]
         return self._change_request(endpoint_name, id, updates, original)
 
-    def system_update(self, endpoint_name, id, updates, original):
+    def system_update(self, endpoint_name, id, updates, original, change_request=False, push_notification=True):
         """Only update what is provided, without affecting etag.
 
         This is useful when you want to make some changes without affecting users.
@@ -234,21 +238,30 @@ class EveBackend:
         :param id: document id
         :param updates: changes made to document
         :param original: original document
+        :param change_request: if True it will allow you to use other mongo operations than `$set`
+        :param push_notification: if False it won't send resource: notifications for update
         """
-        updates.setdefault(config.LAST_UPDATED, utcnow())
+        if not change_request:
+            updates.setdefault(config.LAST_UPDATED, utcnow())
         updated = original.copy()
         updated.pop(config.ETAG, None)  # make sure we update
-        return self._change_request(endpoint_name, id, updates, updated)
+        return self._change_request(
+            endpoint_name, id, updates, updated, change_request=change_request, push_notification=push_notification
+        )
 
-    def _change_request(self, endpoint_name, id, updates, original):
+    def _change_request(self, endpoint_name, id, updates, original, change_request=False, push_notification=True):
         backend = self._backend(endpoint_name)
         search_backend = self._lookup_backend(endpoint_name)
 
         try:
-            backend.update(endpoint_name, id, updates, original)
-            push_notification(
-                "resource:updated", _id=str(id), resource=endpoint_name, fields=get_diff_keys(updates, original)
-            )
+            if change_request:  # allows using mongo operations other than $set
+                backend._change_request(endpoint_name, id, updates, original)
+            else:
+                backend.update(endpoint_name, id, updates, original)
+            if push_notification:
+                self._push_resource_notification(
+                    "updated", endpoint_name, _id=str(id), fields=get_diff_keys(updates, original)
+                )
         except eve.io.base.DataLayer.OriginalChangedError:
             if not backend.find_one(endpoint_name, req=None, _id=id) and search_backend:
                 # item is in elastic, not in mongo - not good
@@ -374,7 +387,7 @@ class EveBackend:
             backend.remove(endpoint_name, {config.ID_FIELD: {"$in": removed_ids}})
             logger.info("Removed %d documents from %s.", len(removed_ids), endpoint_name)
             for doc in docs:
-                push_notification("resource:deleted", _id=str(doc["_id"]), resource=endpoint_name)
+                self._push_resource_notification("deleted", endpoint_name, _id=str(doc["_id"]))
         else:
             logger.warn("No documents for %s resource were deleted.", endpoint_name)
         return removed_ids
@@ -385,12 +398,25 @@ class EveBackend:
         :param ids:
         :return:
         """
+
+        self.delete_from_mongo(endpoint_name, {config.ID_FIELD: {"$in": ids}})
+        return ids
+
+    def delete_from_mongo(self, endpoint_name: str, lookup: Dict[str, Any]):
+        """Delete from mongo using a lookup without searching or checking
+
+        .. versionadded:: 2.4.0
+
+        :param str endpoint_name: The name of the resource to delete documents for
+        :param dict lookup: The MongoDB query to use for deleting documents
+        :raises SuperdeskApiError.forbiddenError if search is enabled for this resource
+        """
+
         backend = self._backend(endpoint_name)
         search_backend = self._lookup_backend(endpoint_name)
         if search_backend:
             raise SuperdeskApiError.forbiddenError(message="Can not remove from endpoint with a defined search")
-        backend.remove(endpoint_name, {config.ID_FIELD: {"$in": ids}})
-        return len(ids)
+        backend.remove(endpoint_name, lookup)
 
     def remove_from_search(self, endpoint_name, doc):
         """Remove document from search backend.
@@ -441,3 +467,13 @@ class EveBackend:
             # https://docs.mongodb.com/manual/reference/collation/
             if "collation" in req.args:
                 cursor.collation(Collation(**std_json.loads(req.args["collation"])))
+
+    def notify_on_change(self, endpoint_name):
+        """Test if we should push notifications for given resource."""
+        source_config = app.config["DOMAIN"][endpoint_name]
+        return source_config["notifications"] is True
+
+    def _push_resource_notification(self, action: Literal["created", "updated", "deleted"], endpoint_name, **kwargs):
+        resource = self._datasource(endpoint_name)
+        if self.notify_on_change(resource):
+            _push_notification(f"resource:{action}", resource=resource, **kwargs)
