@@ -8,7 +8,7 @@
 # AUTHORS and LICENSE files distributed with this source code, or
 # at https://www.sourcefabric.org/superdesk/license
 
-from typing import List, Dict
+from typing import List, Dict, Optional
 import traceback
 import requests
 from superdesk.errors import IngestApiError, SuperdeskIngestError
@@ -65,7 +65,7 @@ class HTTPFeedingServiceBase(FeedingService):
     ]
 
     # override this parameter with the main URL to use
-    HTTP_URL = None
+    HTTP_URL: Optional[str] = None
     # timeout in seconds
     HTTP_TIMEOUT = 30
     # if some parameters are used in every request, put them here
@@ -95,16 +95,16 @@ class HTTPFeedingServiceBase(FeedingService):
             "type": "text",
             "label": "Username",
             "placeholder": "Username",
-            "required_expression": "{auth_required}",
-            "show_expression": "{auth_required}",
+            "required_expression": "provider.config.auth_required === true",
+            "show_expression": "provider.config.auth_required === true",
         },
         {
             "id": "password",
             "type": "password",
             "label": "Password",
             "placeholder": "Password",
-            "required_expression": "{auth_required}",
-            "show_expression": "{auth_required}",
+            "required_expression": "provider.config.auth_required === true",
+            "show_expression": "provider.config.auth_required === true",
         },
     ]
 
