@@ -11,7 +11,7 @@
 from typing import NamedTuple
 from copy import deepcopy
 
-from superdesk.resource import Resource, not_analyzed, not_indexed, not_enabled, text_with_keyword
+from superdesk.resource import Resource, not_analyzed, not_indexed, not_enabled, text_with_keyword, not_dynamic
 from .packages import LINKED_IN_PACKAGES, PACKAGE
 from eve.utils import config
 from superdesk.utils import SuperdeskBaseEnum
@@ -205,6 +205,7 @@ metadata_schema = {
             "properties": {
                 "qcode": not_analyzed,
                 "name": not_analyzed,
+                "scheme": not_analyzed,
             },
         },
     },
@@ -253,7 +254,10 @@ metadata_schema = {
                     "analyzer": "phrase_prefix_analyzer",
                     "search_analyzer": "phrase_prefix_analyzer",
                     "fielddata": True,
-                }
+                },
+                "keyword": {
+                    "type": "keyword",
+                },
             },
         },
     },
@@ -483,6 +487,7 @@ metadata_schema = {
             "uri": {"type": "string"},
             "guid": {"type": "string"},
             "type": {"type": "string"},
+            "source": {"type": "string", "nullable": True},
         },
         "mapping": {
             "type": "object",
@@ -492,6 +497,7 @@ metadata_schema = {
                 "uri": not_analyzed,
                 "guid": not_analyzed,
                 "type": not_analyzed,
+                "source": not_analyzed,
             },
         },
     },
@@ -626,7 +632,7 @@ metadata_schema = {
     "extra": {
         "type": "dict",
         "schema": {},
-        "mapping": not_enabled,
+        "mapping": not_dynamic,
         "allow_unknown": True,
     },
     "attachments": {
@@ -659,6 +665,7 @@ metadata_schema = {
     "embargoed": {"type": "datetime"},
     "embargoed_text": {"type": "string", "mapping": not_indexed},
     "marked_for_user": Resource.rel("users", required=False, nullable=True),
+    "marked_for_sign_off": {"type": "string", "nullable": True},
     "broadcast": {
         "type": "dict",
         "schema": {
@@ -683,6 +690,11 @@ metadata_schema = {
     "used": {"type": "boolean"},
     "used_count": {"type": "integer"},
     "used_updated": {"type": "datetime"},
+    "metrics": {
+        "type": "dict",
+        "readonly": True,
+        "allow_unknown": True,
+    },
     # system fields
     "_type": {"type": "string", "mapping": None},
     "operation": {"type": "string"},
