@@ -22,13 +22,17 @@
 
 import ast
 import logging
-import superdesk
 from flask import request
+from flask_babel import _
+
+import superdesk
 from superdesk.errors import SuperdeskApiError
 from superdesk.notification import push_notification
-from .utils import get_file_from_sams
 from superdesk.storage.superdesk_file import generate_response_for_file
+
 from apps.auth import get_auth, get_user_id
+
+from .utils import get_file_from_sams, get_attachments_from_asset_id
 from .client import get_sams_client
 
 logger = logging.getLogger(__name__)
@@ -94,6 +98,9 @@ def delete(item_id):
     except KeyError:
         raise SuperdeskApiError.badRequestError("If-Match field missing in header")
 
+    if get_attachments_from_asset_id(item_id).count():
+        raise SuperdeskApiError.badRequestError(_("Asset is attached to a news item, cannot delete"))
+
     delete_response = get_sams_client().assets.delete(item_id=item_id, headers={"If-Match": etag})
     if delete_response.status_code != 204:
         return delete_response.json(), delete_response.status_code
@@ -204,3 +211,17 @@ def unlock_asset_by_user(user_id, session_id):
             "sams:asset:session_unlock", user_id=get_user_id(True), session_id=get_auth()["_id"], extension="sams"
         )
     return unlock_asset_response.status_code
+
+
+@assets_bp.route("/sams/assets/tags", methods=["GET"])
+def get_assets_tags():
+
+    search_query = request.args.to_dict().get("query")
+    query = {
+        "bool": {
+            "must": [{"query_string": {"query": search_query, "default_field": "tags.name", "default_operator": "AND"}}]
+        }
+    }
+
+    tags_response = get_sams_client().assets.get_tag_codes(query=query if search_query else search_query)
+    return tags_response
