@@ -27,6 +27,10 @@ class SuperdeskMediaStorage(MediaStorage, MimetypeMixin):
     def url_for_download(self, media, content_type=None):
         raise NotImplementedError
 
+    @abc.abstractmethod
+    def url_for_external(self, media_id: str, resource: str = None) -> str:
+        raise NotImplementedError
+
     @abc.abstractmethod
     def get_by_filename(self, filename):
         raise NotImplementedError
@@ -50,7 +54,7 @@ class SimpleMediaStorage(GridFSMediaStorage):
         return self._fs[px]
 
 
-def init_app(app):
+def init_app(app) -> None:
     app.storage = SimpleMediaStorage(app)
 
 
@@ -59,3 +63,5 @@ from .desk_media_storage import SuperdeskGridFSMediaStorage  # noqa
 from .amazon_media_storage import AmazonMediaStorage  # noqa
 
 from .migrate import MigrateMediaCommand  # noqa
+
+import superdesk.storage.fix_links  # noqa
