@@ -13,7 +13,7 @@ import superdesk
 
 from flask import current_app
 from collections import OrderedDict
-from typing import Optional, Dict, List
+from typing import Optional, Dict, List, Set
 from urllib.parse import urljoin
 from superdesk.text_utils import get_text
 from superdesk.errors import SuperdeskApiError
@@ -74,13 +74,16 @@ class IMatrics(AIServiceBase):
         tag_data = {
             "name": concept["title"],
             "qcode": concept["uuid"],
+            "parent": concept.get("broader") or None,
             "source": "imatrics",
+            "aliases": concept.get("aliases", []),
+            "original_source": concept.get("source"),
             "altids": {
                 "imatrics": concept["uuid"],
             },
         }
 
-        if concept.get("shortDescription") and concept["shortDescription"].strip():
+        if concept.get("shortDescription") and concept["shortDescription"].strip() != "NaN":
             tag_data["description"] = concept["shortDescription"].strip()
 
         try:
@@ -132,6 +135,13 @@ class IMatrics(AIServiceBase):
                 )
             )
 
+    def _parse_concepts(self, analyzed_data: Dict[str, List], concepts: List[dict]) -> None:
+        """Parse response data, convert iMatrics concepts to SD data and add them to analyzed_data"""
+        for concept in concepts:
+            tag_data = self.concept2tag_data(concept)
+            tag_type = tag_data.pop("type")
+            analyzed_data.setdefault(tag_type, []).append(tag_data)
+
     def analyze(self, item: dict) -> dict:
         """Analyze article to get tagging suggestions"""
         if not self.base_url or not self.user or not self.key:
@@ -149,21 +159,25 @@ class IMatrics(AIServiceBase):
             "pubStatus": False,
             "headline": headline,
             "body": body,
+            "language": item["language"],
         }
 
-        r_data = self._request("article/concept", data)
+        r_data = self._request(
+            "article/analysis",
+            data,
+            params=dict(conceptFields="uuid,title,type,shortDescription,aliases,source,weight,broader"),
+        )
 
         analyzed_data: Dict[str, List] = {}
-
-        for concept in r_data:
-            tag_data = self.concept2tag_data(concept)
-            tag_type = tag_data.pop("type")
-            analyzed_data.setdefault(tag_type, []).append(tag_data)
+        self._parse_concepts(analyzed_data, r_data["concepts"] + r_data["broader"])
 
         for tags in analyzed_data.values():
-            tags.sort(key=lambda d: d["weight"], reverse=True)
+            tags.sort(key=lambda d: d.get("weight", 0), reverse=True)
             for tag in tags:
-                del tag["weight"]
+                try:
+                    del tag["weight"]
+                except KeyError:
+                    pass
 
         return analyzed_data
 
