@@ -17,15 +17,17 @@ from superdesk.etree import etree
 class TestANACase(TestCase):
     def setUp(self):
         dirname = os.path.dirname(os.path.realpath(__file__))
-        fixture = os.path.normpath(os.path.join(dirname, '../fixtures', 'ana1.xml'))
-        provider = {'name': 'Test', 'source': 'ANA'}
-        with open(fixture, 'rb') as f:
+        fixture = os.path.normpath(os.path.join(dirname, "../fixtures", "ana1.xml"))
+        provider = {"name": "Test", "source": "ANA"}
+        with open(fixture, "rb") as f:
             self.item = ANANewsMLOneFeedParser().parse(etree.fromstring(f.read()), provider)
 
     def test_headline(self):
-        self.assertEqual(self.item['headline'], 'Wage employment balance positive in Jan-March')
-        self.assertEqual(self.item['subject'][0], {'qcode': '04008004', 'name': 'economic indicator'})
-        self.assertEqual(self.item['dateline']['text'], 'ATHENS, April 4 ANA -')
-        self.assertTrue(self.item['body_html'].startswith('<p>Wage employment'))
-        self.assertTrue(self.item['body_html'].endswith(' job positions.</p>\n<p> </p>'), )
-        self.assertEqual(self.item['word_count'], '115')
+        self.assertEqual(self.item["headline"], "Wage employment balance positive in Jan-March")
+        self.assertEqual(self.item["subject"][0], {"qcode": "04008004", "name": "economic indicator"})
+        self.assertEqual(self.item["dateline"]["text"], "ATHENS, April 4 ANA -")
+        self.assertTrue(self.item["body_html"].startswith("<p>Wage employment"))
+        self.assertTrue(
+            self.item["body_html"].endswith(" job positions.</p>\n<p> </p>"),
+        )
+        self.assertEqual(self.item["word_count"], "115")
